@@ -41,12 +41,13 @@ class AnsibleProcessor(BaseProcessor):
     __name__ = "ansible"
     __description__ = "Fedora Infrastructure Ansible Runs"
     __link__ = "http://infrastructure.fedoraproject.org/cgit/ansible.git"
+    __icon__ = "https://apps.fedoraproject.org/img/icons/ansible.png"
     __docs__ = \
         "https://fedoraproject.org/wiki/Infrastructure_ansible_migration"
     __obj__ = "Ansible Runs"
 
     def subtitle(self, msg, **config):
-        user = msg['msg']['userid']
+        user = msg['msg'].get('userid', '(no user specified)')
         controlled, playbook = relative_playbook(msg['msg']['playbook'])
 
         if 'ansible.playbook.start' in msg['topic']:
@@ -58,8 +59,9 @@ class AnsibleProcessor(BaseProcessor):
         return ""
 
     def secondary_icon(self, msg, **config):
-        user = msg['msg']['userid']
-        return gravatar_url(user)
+        user = msg['msg'].get('userid')
+        if user:
+            return gravatar_url(user)
 
     def link(self, msg, **config):
         base = "http://infrastructure.fedoraproject.org/cgit/ansible.git/tree/"
@@ -70,7 +72,10 @@ class AnsibleProcessor(BaseProcessor):
             return base + playbook
 
     def usernames(self, msg, **config):
-        return set([msg['msg']['userid']])
+        user = msg['msg'].get('userid')
+        if user:
+            return set([user])
+        return set()
 
     def objects(self, msg, **config):
         controlled, playbook = relative_playbook(msg['msg']['playbook'])
