@@ -1,5 +1,5 @@
 # This file is part of fedmsg.
-# Copyright (C) 2012 Red Hat, Inc.
+# Copyright (C) 2012-2014 Red Hat, Inc.
 #
 # fedmsg is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,15 +18,13 @@
 # Authors:  Ralph Bean <rbean@redhat.com>
 #           Luke Macken <lmacken@redhat.com>
 
+import re
+
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
 from fasshim import gravatar_url
 
-
-def _u2p(update):
-    """ Take an update, and return the package name """
-    # TODO -- make this unnecessary by having bodhi emit the
-    # package name (and not just the update name) to begin with.
-    return [build.rsplit('-', 2)[0] for build in update.split(',')]
+import conglomerators.bodhi.requests
+import conglomerators.bodhi.comments
 
 
 def get_sync_product(msg):
@@ -45,14 +43,38 @@ def is_ftp_sync(msg):
     return 'bodhi.updates.' in msg['topic'] and msg['topic'].endswith('.sync')
 
 
+def author_link(username):
+    return "<a href='https://admin.fedoraproject.org/updates/" + \
+        "user/{user}'>{user}</a>".format(user=username)
+
+
+def update_link(title):
+    return "<a href='https://admin.fedoraproject.org/updates/" + \
+        "{title}'>{title}</a>".format(title=title)
+
+
 class BodhiProcessor(BaseProcessor):
     __name__ = "Bodhi"
     __description__ = "the Fedora update system"
     __link__ = "https://admin.fedoraproject.org/updates"
-    __docs__ = "http://fedoraproject.org/wiki/Bodhi"
+    __docs__ = "https://fedoraproject.org/wiki/Bodhi"
     __obj__ = "Package Updates"
     __icon__ = ("https://admin.fedoraproject.org/updates"
                 "/static/images/bodhi-icon-48.png")
+    conglomerators = [
+        conglomerators.bodhi.requests.ByUserAndPackageTesting,
+        conglomerators.bodhi.requests.ByUserAndPackageStable,
+        conglomerators.bodhi.requests.ByPackage,
+        conglomerators.bodhi.requests.ByUser,
+        conglomerators.bodhi.comments.ByUpdate,
+        conglomerators.bodhi.comments.ByUser,
+    ]
+
+    def _u2p(self, update):
+        """ Take an update, and return the package name """
+        # TODO -- make this unnecessary by having bodhi emit the
+        # package name (and not just the update name) to begin with.
+        return [build.rsplit('-', 2)[0] for build in update.split(',')]
 
     def secondary_icon(self, msg, **config):
         username = ''
@@ -68,6 +90,8 @@ class BodhiProcessor(BaseProcessor):
         return gravatar
 
     def subtitle(self, msg, **config):
+        markup = config.get('markup', False)
+
         if is_ftp_sync(msg):
             product = get_sync_product(msg)
             msg = msg['msg']
@@ -86,7 +110,15 @@ class BodhiProcessor(BaseProcessor):
             tmpl = self._(
                 "{author} commented on bodhi update {title} (karma: {karma})"
             )
-            return tmpl.format(author=author, karma=karma, title=title)
+            if not markup:
+                return tmpl.format(author=author, karma=karma, title=title)
+            else:
+                return tmpl.format(
+                    author=author_link(author),
+                    title=update_link(title),
+                    karma=karma,
+                )
+
         elif 'bodhi.update.complete.' in msg['topic']:
             author = msg['msg']['update']['submitter']
             package = msg['msg']['update']['title']
@@ -102,12 +134,18 @@ class BodhiProcessor(BaseProcessor):
             if status in ('unpush', 'obsolete', 'revoke'):
                 # make our status past-tense
                 status = status + (status[-1] == 'e' and 'd' or 'ed')
-                tmpl = self._("{author} {status} {title}").format(
-                    author=author, status=status, title=title)
+                tmpl = self._("{author} {status} {title}")
             else:
-                tmpl = self._("{author} submitted {title} to {status}").format(
-                    author=author, status=status, title=title)
-            return tmpl
+                tmpl = self._("{author} submitted {title} to {status}")
+
+            if not markup:
+                return tmpl.format(author=author, title=title, status=status)
+            else:
+                return tmpl.format(
+                    author=author_link(author),
+                    title=update_link(title),
+                    status=status,
+                )
         elif 'bodhi.mashtask.mashing' in msg['topic']:
             repo = msg['msg']['repo']
             tmpl = self._("bodhi masher is mashing {repo}")
@@ -126,11 +164,25 @@ class BodhiProcessor(BaseProcessor):
             return self._("bodhi masher finished waiting on mirror repos "
                           "to sync")
         elif 'bodhi.buildroot_override.tag' in msg['topic']:
-            return self._("{submitter} submitted a buildroot override " +
-                          "for {build}").format(**msg['msg']['override'])
+            tmpl = self._("{submitter} submitted a buildroot override " +
+                          "for {build}")
+            if markup:
+                return tmpl.format(
+                    submitter=author_link(msg['msg']['override']['submitter']),
+                    build=msg['msg']['override']['build'],
+                )
+            else:
+                return tmpl.format(**msg['msg']['override'])
         elif 'bodhi.buildroot_override.untag' in msg['topic']:
-            return self._("{submitter} expired a buildroot override " +
-                          "for {build}").format(**msg['msg']['override'])
+            tmpl = self._("{submitter} expired a buildroot override " +
+                          "for {build}")
+            if markup:
+                return tmpl.format(
+                    submitter=author_link(msg['msg']['override']['submitter']),
+                    build=msg['msg']['override']['build'],
+                )
+            else:
+                return tmpl.format(**msg['msg']['override'])
         else:
             raise NotImplementedError("%r" % msg)
 
@@ -158,13 +210,13 @@ class BodhiProcessor(BaseProcessor):
 
     def packages(self, msg, **config):
         if 'bodhi.update.comment' in msg['topic']:
-            return set(_u2p(msg['msg']['comment']['update_title']))
+            return set(self._u2p(msg['msg']['comment']['update_title']))
         elif 'bodhi.update.complete' in msg['topic']:
-            return set(_u2p(msg['msg']['update']['title']))
+            return set(self._u2p(msg['msg']['update']['title']))
         elif 'bodhi.update.request' in msg['topic']:
-            return set(_u2p(msg['msg']['update']['title']))
+            return set(self._u2p(msg['msg']['update']['title']))
         elif 'bodhi.buildroot_override.' in msg['topic']:
-            return set(_u2p(msg['msg']['override']['build']))
+            return set(self._u2p(msg['msg']['override']['build']))
 
         return set()
 
@@ -182,6 +234,12 @@ class BodhiProcessor(BaseProcessor):
         except KeyError:
             pass
 
+        if 'comment' in msg['msg']:
+            text = msg['msg']['comment']['text']
+            mentions = re.findall('@\w+', text)
+            for mention in mentions:
+                users.append(mention[1:])
+
         return set(users)
 
     def objects(self, msg, **config):
@@ -194,22 +252,22 @@ class BodhiProcessor(BaseProcessor):
         elif 'bodhi.update.comment' in msg['topic']:
             return set([
                 'packages/' + p for p in
-                _u2p(msg['msg']['comment']['update_title'])
+                self._u2p(msg['msg']['comment']['update_title'])
             ])
         elif 'bodhi.update.complete' in msg['topic']:
             return set([
                 'packages/' + p for p in
-                _u2p(msg['msg']['update']['title'])
+                self._u2p(msg['msg']['update']['title'])
             ])
         elif 'bodhi.update.request' in msg['topic']:
             return set([
                 'packages/' + p for p in
-                _u2p(msg['msg']['update']['title'])
+                self._u2p(msg['msg']['update']['title'])
             ])
         elif 'bodhi.buildroot_override.' in msg['topic']:
             return set([
                 'packages/' + p for p in
-                _u2p(msg['msg']['override']['build'])
+                self._u2p(msg['msg']['override']['build'])
             ])
 
         return set()
